Fix mistake in -password and -username options, tweak the (doomed) sfl repository screen scraping
authorWilliam Roberts <williamr@symbian.org>
Tue, 23 Jun 2009 16:06:00 +0100
changeset 13 dda0176e838b
parent 12 319764718a57
child 14 f57f08cb4e1d
Fix mistake in -password and -username options, tweak the (doomed) sfl repository screen scraping
clone_all_packages.pl
--- a/clone_all_packages.pl	Tue Jun 23 15:31:56 2009 +0100
+++ b/clone_all_packages.pl	Tue Jun 23 16:06:00 2009 +0100
@@ -66,8 +66,8 @@
 my $help = 0;
 
 if (!GetOptions(
-    "u|username" => \$username,
-    "p|password" => \$password,
+    "u|username=s" => \$username,
+    "p|password=s" => \$password,
     "m|mirror" => \$mirror, 
     "r|retries=i" => \$retries,
     "v|verbose" => \$verbose,
@@ -368,7 +368,7 @@
     my @oss_packages = ($res->content =~ m/<td><a href="\/(oss\/[^"]+)\/?">/g);  # umatched "
     print join ("\n\t",@oss_packages), "\n";
 
     # Request the oss package list
     $res = $ua->request(GET "https://$username:$password\@$hostname/sfl");
   
     # Check the outcome of the response
@@ -378,6 +378,7 @@
       }
     
     my @sfl_packages = ($res->content =~ m/<td><a href="\/(sfl\/[^"]+)\/?">/g);  # umatched "
+    print join ("\n\t",@sfl_packages), "\n";
     
     @all_packages = (@sfl_packages, @oss_packages);
     }
@@ -368,7 +368,7 @@
     print join ("\n\t",@oss_packages), "\n";
 
-    # Request the oss package list
+    # Request the sfl package list
     $res = $ua->request(GET "https://$username:$password\@$hostname/sfl");
   